Tol
===
Tol (`tøl`_ n1 (norrønt tól 'reiskap') kollektivt: (små)saker) is a simple helper library for
creating command strings for the command-line.

.. _tøl: https://ordbok.uib.no/perl/ordbok.cgi?OPP=t%C3%B8l&ant_bokmaal=5&ant_nynorsk=5&nynorsk=+&ordbok=begge
